{{
**********************************************
* Object passing methods                     *
* @version 1.0 Jan 13, 2008                  *
* @author Peter Verkaik (verkaik6@zonnet.nl) *
**********************************************
}}


PUB getObjectHandle(target,origin,objects,DATbase,VARbase):value
  '/**
  ' * Get handle for target object to call from origin object
  ' *
  ' * @param target Index of object to call, index determined by OBJ section
  ' * @param origin Index of object from which to call target, index determined by OBJ section
  ' * @param objects Total number of objects declared in OBJ section
  ' * @param DATbase Address where DAT area starts
  ' * @param VARbase Address where VAR area starts
  ' * @return Handle for target object to call from origin object
  ' */
  value := getObjectVarBase(target,objects,DATbase,VARbase)
  value.word[0] := value - getObjectVarBase(origin,objects,DATbase,VARbase)

  
PUB redirect(handle,objects,DATbase,VARbase): oldhandle | i
  '/**
  ' * Redirect an object
  ' *
  ' * @param handle Value that determins which object to redirect and where to
  ' * @param objects Total number of objects declared in OBJ section
  ' * @param DATbase Address where DAT area starts
  ' * @param VARbase Address where VAR area starts
  ' * @return Current handle for object (so the redirection can be undone later)
  ' */
  if (handle == 0) OR (objects =< 0)
    return
  i := 0
  repeat
    oldhandle := getObjectVarBase(i,objects,DATbase,VARbase)
    if oldhandle.word[0] == handle.word[0]  'if same object type
      word[DATbase-((objects-i)*4) + 2] := handle.word[1] - VARbase 'set object VARbase
      return oldhandle
    i++
  until i == objects
  return 0
  

PRI getObjectVarBase(index,objects,DATbase,VARbase):value
  '/**
  ' * Get the VARbase of an object
  ' *
  ' * @param index Index of object for which to set the VARbase, index determined by OBJ section
  ' * @param objects Total number of objects declared in OBJ section
  ' * @param DATbase Address where DAT area starts
  ' * @param VARbase Address where VAR area starts
  ' * @return VARbase of object specified by index
  ' */
  value := long[ DATbase-((objects-index)*4) ]
  value.word[1] += VARbase
  
